@@ -21,12 +21,7 @@ class MarkdownConverter:
     def __init__(self, markdown_content):
         self.markdown_content = self.format_markdown(markdown_content)
         # print(self.markdown_content)
-        self.html_content = markdown.markdown(self.markdown_content, extensions=['tables'])
-        # print(self.html_content)
-        # 逐行处理HTML代码，在<ol>、<li>、<ul>标签前添加换行
-        self.html_content = self._process_html_line_breaks(self.html_content)
-        print('='*50)
-        print(self.html_content)
+        
         FileUtils.create_paths(Config.BASE_PATH)
 
     def format_markdown(self, markdown_text):
@@ -42,9 +37,6 @@ class MarkdownConverter:
         lines = markdown_text.split('\n')
         processed_lines = []
         
-        # 跟踪列表嵌套级别
-        list_levels = []
-        
         for i, line in enumerate(lines):
             line = line.rstrip()  # 移除行尾空白
             
@@ -83,17 +75,17 @@ class MarkdownConverter:
             #         line = line + '\n\n'  # 添加两个换行，确保正确的HTML结构
             
             # 计算当前行的缩进级别
-            line_stripped = line.lstrip()
-            indent_count = len(line) - len(line_stripped)
-            # print(f"line: {line}，indent_count: {indent_count}")
-            if indent_count > 0 :
-                indent_count = indent_count * 2
-            # 保持原有缩进级别，不要翻倍，避免过度缩进
-                tab_indent = ' ' * indent_count
-                a = tab_indent + line_stripped
-                processed_lines.append(a)
-            else:
-                processed_lines.append(line)
+            # line_stripped = line.lstrip()
+            # indent_count = len(line) - len(line_stripped)
+            # # print(f"line: {line}，indent_count: {indent_count}")
+            # if indent_count > 0 :
+            #     indent_count = indent_count * 2
+            # # 保持原有缩进级别，不要翻倍，避免过度缩进
+            #     tab_indent = ' ' * indent_count
+            #     a = tab_indent + line_stripped
+            #     processed_lines.append(a)
+            # else:
+            #     processed_lines.append(line)
         return '\n'.join(processed_lines)
 
     def to_html(self):
@@ -278,6 +270,31 @@ class MarkdownConverter:
         :param file_name
         :return: 返回文件名
         """
+        lines = self.markdown_content.split('\n')
+        processed_lines = []
+        for i, line in enumerate(lines):
+            # 计算当前行的缩进级别
+            line_stripped = line.lstrip()
+            indent_count = len(line) - len(line_stripped)
+            # print(f"line: {line}，indent_count: {indent_count}")
+            if indent_count > 0 :
+                indent_count = indent_count * 2
+            # 保持原有缩进级别，不要翻倍，避免过度缩进
+                tab_indent = ' ' * indent_count
+                a = tab_indent + line_stripped
+                processed_lines.append(a)
+            else:
+                processed_lines.append(line)
+        markdown_content = '\n'.join(processed_lines)
+
+        # markdown 转换为 html
+        html_content = markdown.markdown(markdown_content, extensions=['tables'])
+        # print(self.html_content)
+        # 逐行处理HTML代码，在<ol>、<li>、<ul>标签前添加换行
+        html_content = self._process_html_line_breaks(html_content)
+        print('='*50)
+        print(html_content)
+
         if file_name is None or file_name =='':
             file_name = CommonUtils.generate_uuid() + ".docx"
         elif not file_name.endswith(".docx"):
@@ -287,9 +304,22 @@ class MarkdownConverter:
         font = style.font
         font.name = 'SimSun'
         font.size = Pt(12)
-        soup = BeautifulSoup(self.html_content, 'html.parser')
-        # 只处理顶层的标签，避免重复处理嵌套列表
-        for tag in soup.find_all(['h1', 'h2', 'h3', 'h4','h5','h6', 'p', 'table','img','ul','ol'], recursive=False):
+        soup = BeautifulSoup(html_content, 'html.parser')
+        # 智能处理标签：对列表标签使用recursive=False避免重复，其他标签正常处理
+        for tag in soup.find_all(['h1', 'h2', 'h3', 'h4','h5','h6', 'p', 'table','img','ul','ol']):
+            if tag.name in ['ul', 'ol']:
+                # 跳过嵌套的列表标签，它们会在_process_li_word_content中处理
+                if tag.find_parent(['ul', 'ol']):
+                    continue
+                else:
+                    # 处理顶层列表标签
+                    if tag.name == 'ul':
+                        self._process_list(doc, tag, 'ListBullet', 0)
+                    elif tag.name == 'ol':
+                        self._process_list(doc, tag, 'ListNumber', 0)
+                    continue
+            
+            # 处理非列表标签
             if tag.name == 'h1':
                 heading = doc.add_heading(level=1)
                 heading.alignment = WD_PARAGRAPH_ALIGNMENT.CENTER
